@@ -91,8 +91,8 @@ class Logger:
 
     def __init__(self, name: str,
                  time_format: str = None,
-                 min_loglevel: LogLevel = None,
-                 max_loglevel: LogLevel = None) -> None:
+                 min_loglevel: LogLevel = LogLevel.INFO,
+                 max_loglevel: LogLevel = LogLevel.CRITICAL) -> None:
         """
         Initializes the Logger with the given name, time format, and log
         levels.
@@ -110,13 +110,13 @@ class Logger:
             InvalidLogLevelError: If the provided log levels are not supported.
         """
 
-        if min_loglevel is None:
-            self.min_loglevel: LogLevel = LogLevel.INFO
         self.min_loglevel: LogLevel = min_loglevel
+        if self.min_loglevel is None:
+            self.min_loglevel: LogLevel = LogLevel.INFO
 
-        if max_loglevel is None:
-            self.max_loglevel: LogLevel = LogLevel.INFO
         self.max_loglevel: LogLevel = max_loglevel
+        if self.max_loglevel is None:
+            self.max_loglevel: LogLevel = LogLevel.INFO
 
         self.name: str = name
 
